@@ -28,12 +28,12 @@ class ImageToImageRequest(AbstractModel):
         :param _InputImage: 输入图 Base64 数据。
 算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
 Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
-图片限制：单边分辨率小于2000，转成 Base64 字符串后小于 5MB。
+图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 8MB。
         :type InputImage: str
         :param _InputUrl: 输入图 Url。
 算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
 Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
-图片限制：单边分辨率小于2000，转成 Base64 字符串后小于 5MB。
+图片限制：单边分辨率小于5000，转成 Base64 字符串后小于8MB。
         :type InputUrl: str
         :param _Prompt: 文本描述。
 用于在输入图的基础上引导生成图效果，增加生成结果中出现描述内容的可能。
@@ -48,7 +48,8 @@ Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
 推荐使用且只使用一种风格。不传默认使用201（日系动漫风格）。
         :type Styles: list of str
         :param _ResultConfig: 生成图结果的配置，包括输出图片分辨率和尺寸等。
-支持生成以下分辨率的图片：origin（与输入图分辨率一致）、768:768（1:1）、768:1024（3:4）、1024:768（4:3），不传默认使用origin。
+支持生成以下分辨率的图片：origin（与输入图分辨率一致，长边最高为2000，超出将做等比例缩小）、768:768（1:1）、768:1024（3:4）、1024:768（4:3）。
+不传默认使用origin。
         :type ResultConfig: :class:`tencentcloud.aiart.v20221229.models.ResultConfig`
         :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
 1：添加标识。
@@ -408,6 +409,8 @@ class QueryTextToImageProJobResponse(AbstractModel):
         :param _ResultDetails: 结果 detail 数组，Success 代表成功。
 
         :type ResultDetails: list of str
+        :param _RevisedPrompt: 对应 SubmitTextToImageProJob 接口中 Revise 参数。开启扩写时，返回扩写后的 prompt 文本。 如果关闭扩写，将直接返回原始输入的 prompt。
+        :type RevisedPrompt: list of str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -417,6 +420,7 @@ class QueryTextToImageProJobResponse(AbstractModel):
         self._JobErrorMsg = None
         self._ResultImage = None
         self._ResultDetails = None
+        self._RevisedPrompt = None
         self._RequestId = None
 
     @property
@@ -467,6 +471,14 @@ class QueryTextToImageProJobResponse(AbstractModel):
     def ResultDetails(self, ResultDetails):
         self._ResultDetails = ResultDetails
 
+    @property
+    def RevisedPrompt(self):
+        return self._RevisedPrompt
+
+    @RevisedPrompt.setter
+    def RevisedPrompt(self, RevisedPrompt):
+        self._RevisedPrompt = RevisedPrompt
+
     @property
     def RequestId(self):
         return self._RequestId
@@ -483,6 +495,7 @@ class QueryTextToImageProJobResponse(AbstractModel):
         self._JobErrorMsg = params.get("JobErrorMsg")
         self._ResultImage = params.get("ResultImage")
         self._ResultDetails = params.get("ResultDetails")
+        self._RevisedPrompt = params.get("RevisedPrompt")
         self._RequestId = params.get("RequestId")
 
 
@@ -495,9 +508,9 @@ class ResultConfig(AbstractModel):
         r"""
         :param _Resolution: 生成图分辨率
 
-智能文生图支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）、1024:1024（1:1）、720:1280（9:16）、1280:720（16:9）、768:1280（3:5）、1280:768（5:3）、1080:1920（9:16）、1920:1080（16:9），不传默认使用768:768
+智能文生图支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）、1024:1024（1:1）、720:1280（9:16）、1280:720（16:9）、768:1280（3:5）、1280:768（5:3）、1080:1920（9:16）、1920:1080（16:9），不传默认使用768:768。
 
-智能图生图支持生成以下分辨率的图片：origin（与输入图分辨率一致）、768:768（1:1）、768:1024（3:4）、1024:768（4:3），不传默认使用origin，如果指定生成的长宽比与输入图长宽比差异过大可能导致图片内容被裁剪
+智能图生图支持生成以下分辨率的图片：origin（与输入图分辨率一致，长边最高为2000，超出将做等比例缩小）、768:768（1:1）、768:1024（3:4）、1024:768（4:3），不传默认使用origin，如果指定生成的长宽比与输入图长宽比差异过大可能导致图片内容被裁剪。
         :type Resolution: str
         """
         self._Resolution = None
@@ -552,12 +565,18 @@ class SubmitTextToImageProJobRequest(AbstractModel):
 engine1  
 engine2
         :type Engine: str
+        :param _Revise: prompt 扩写开关。1为开启，0为关闭，不传默认开启。
+开启扩写后，将自动扩写原始输入的 prompt 并使用扩写后的 prompt 生成图片，返回生成图片结果时将一并返回扩写后的 prompt 文本。
+如果关闭扩写，将直接使用原始输入的 prompt 生成图片。
+建议开启，在多数场景下可提升生成图片效果、丰富生成图片细节。
+        :type Revise: int
         """
         self._Prompt = None
         self._Style = None
         self._Resolution = None
         self._LogoAdd = None
         self._Engine = None
+        self._Revise = None
 
     @property
     def Prompt(self):
@@ -599,6 +618,14 @@ engine2
     def Engine(self, Engine):
         self._Engine = Engine
 
+    @property
+    def Revise(self):
+        return self._Revise
+
+    @Revise.setter
+    def Revise(self, Revise):
+        self._Revise = Revise
+
 
     def _deserialize(self, params):
         self._Prompt = params.get("Prompt")
@@ -606,6 +633,7 @@ engine2
         self._Resolution = params.get("Resolution")
         self._LogoAdd = params.get("LogoAdd")
         self._Engine = params.get("Engine")
+        self._Revise = params.get("Revise")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
