@@ -72,6 +72,98 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def AddShareUnit(self, request):
+        """创建共享单元，只有企业组织管理员可创建。
+
+        :param request: Request instance for AddShareUnit.
+        :type request: :class:`tencentcloud.organization.v20210331.models.AddShareUnitRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.AddShareUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddShareUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddShareUnitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def AddShareUnitMembers(self, request):
+        """添加共享单元成员
+
+        :param request: Request instance for AddShareUnitMembers.
+        :type request: :class:`tencentcloud.organization.v20210331.models.AddShareUnitMembersRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.AddShareUnitMembersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddShareUnitMembers", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddShareUnitMembersResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def AddShareUnitResources(self, request):
+        """添加共享单元资源
+
+        :param request: Request instance for AddShareUnitResources.
+        :type request: :class:`tencentcloud.organization.v20210331.models.AddShareUnitResourcesRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.AddShareUnitResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddShareUnitResources", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddShareUnitResourcesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def AttachPolicy(self, request):
+        """绑定策略
+
+        :param request: Request instance for AttachPolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.AttachPolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.AttachPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AttachPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.AttachPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BindOrganizationMemberAuthAccount(self, request):
         """绑定组织成员和组织管理员子账号的授权关系
 
@@ -118,6 +210,29 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CheckAccountDelete(self, request):
+        """成员账号删除检查
+
+        :param request: Request instance for CheckAccountDelete.
+        :type request: :class:`tencentcloud.organization.v20210331.models.CheckAccountDeleteRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.CheckAccountDeleteResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckAccountDelete", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckAccountDeleteResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateOrganization(self, request):
         """创建企业组织
 
@@ -256,6 +371,52 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreatePolicy(self, request):
+        """创建一个特殊类型的策略，你可以关联到企业组织Root节点、企业单元或者企业的成员账号。
+
+        :param request: Request instance for CreatePolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.CreatePolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.CreatePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreatePolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreatePolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteAccount(self, request):
+        """删除成员账号
+
+        :param request: Request instance for DeleteAccount.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DeleteAccountRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DeleteAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAccount", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAccountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteOrganization(self, request):
         """删除企业组织
 
@@ -394,6 +555,98 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeletePolicy(self, request):
+        """删除策略
+
+        :param request: Request instance for DeletePolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DeletePolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DeletePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeletePolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeletePolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteShareUnit(self, request):
+        """删除共享单元。
+
+        :param request: Request instance for DeleteShareUnit.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteShareUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteShareUnitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteShareUnitMembers(self, request):
+        """删除共享单元成员
+
+        :param request: Request instance for DeleteShareUnitMembers.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitMembersRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitMembersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteShareUnitMembers", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteShareUnitMembersResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteShareUnitResources(self, request):
+        """删除共享单元资源
+
+        :param request: Request instance for DeleteShareUnitResources.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitResourcesRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DeleteShareUnitResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteShareUnitResources", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteShareUnitResourcesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeOrganization(self, request):
         """获取企业组织信息
 
@@ -647,6 +900,213 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribePolicy(self, request):
+        """本接口（DescribePolicy）可用于查询查看策略详情。
+
+        :param request: Request instance for DescribePolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribePolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribePolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribePolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribePolicyConfig(self, request):
+        """本接口（DescribePolicyConfig）可用于查询企业组织策略配置
+
+        :param request: Request instance for DescribePolicyConfig.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribePolicyConfigRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribePolicyConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribePolicyConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribePolicyConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeShareAreas(self, request):
+        """获取可共享地域列表
+
+        :param request: Request instance for DescribeShareAreas.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribeShareAreasRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribeShareAreasResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeShareAreas", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeShareAreasResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeShareUnitMembers(self, request):
+        """获取共享单元成员列表。
+
+        :param request: Request instance for DescribeShareUnitMembers.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitMembersRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitMembersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeShareUnitMembers", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeShareUnitMembersResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeShareUnitResources(self, request):
+        """获取共享单元资源列表。
+
+        :param request: Request instance for DescribeShareUnitResources.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitResourcesRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeShareUnitResources", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeShareUnitResourcesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeShareUnits(self, request):
+        """获取共享单元列表。
+
+        :param request: Request instance for DescribeShareUnits.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitsRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribeShareUnitsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeShareUnits", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeShareUnitsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DetachPolicy(self, request):
+        """解绑策略
+
+        :param request: Request instance for DetachPolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DetachPolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DetachPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DetachPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DetachPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DisablePolicyType(self, request):
+        """禁用策略类型
+
+        :param request: Request instance for DisablePolicyType.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DisablePolicyTypeRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DisablePolicyTypeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DisablePolicyType", params, headers=headers)
+            response = json.loads(body)
+            model = models.DisablePolicyTypeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def EnablePolicyType(self, request):
+        """启用策略类型
+
+        :param request: Request instance for EnablePolicyType.
+        :type request: :class:`tencentcloud.organization.v20210331.models.EnablePolicyTypeRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.EnablePolicyTypeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnablePolicyType", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnablePolicyTypeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListOrganizationIdentity(self, request):
         """获取组织成员访问身份列表
 
@@ -670,6 +1130,75 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListPolicies(self, request):
+        """本接口（ListPolicies）可用于查询查看策略列表数据
+
+        :param request: Request instance for ListPolicies.
+        :type request: :class:`tencentcloud.organization.v20210331.models.ListPoliciesRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.ListPoliciesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListPolicies", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListPoliciesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListPoliciesForTarget(self, request):
+        """本接口（ListPoliciesForTarget）查询目标关联的策略列表
+
+        :param request: Request instance for ListPoliciesForTarget.
+        :type request: :class:`tencentcloud.organization.v20210331.models.ListPoliciesForTargetRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.ListPoliciesForTargetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListPoliciesForTarget", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListPoliciesForTargetResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListTargetsForPolicy(self, request):
+        """本接口（ListTargetsForPolicy）查询某个指定策略关联的目标列表
+
+        :param request: Request instance for ListTargetsForPolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.ListTargetsForPolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.ListTargetsForPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListTargetsForPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListTargetsForPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def MoveOrganizationNodeMembers(self, request):
         """移动成员到指定企业组织节点
 
@@ -801,6 +1330,52 @@ class OrganizationClient(AbstractClient):
             model = models.UpdateOrganizationNodeResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdatePolicy(self, request):
+        """编辑策略
+
+        :param request: Request instance for UpdatePolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.UpdatePolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.UpdatePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdatePolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdatePolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateShareUnit(self, request):
+        """更新共享单元。
+
+        :param request: Request instance for UpdateShareUnit.
+        :type request: :class:`tencentcloud.organization.v20210331.models.UpdateShareUnitRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.UpdateShareUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateShareUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateShareUnitResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
